@@ -5,17 +5,17 @@ app = FastAPI()
 
 
 @app.get("/int/{param:int}")
-def int_convertor(param: int = Path(...)):
+def int_convertor(param: int = Path()):
     return {"int": param}
 
 
 @app.get("/float/{param:float}")
-def float_convertor(param: float = Path(...)):
+def float_convertor(param: float = Path()):
     return {"float": param}
 
 
 @app.get("/path/{param:path}")
-def path_convertor(param: str = Path(...)):
+def path_convertor(param: str = Path()):
     return {"path": param}
 
 
@@ -27,7 +27,7 @@ def test_route_converters_int():
     response = client.get("/int/5")
     assert response.status_code == 200, response.text
     assert response.json() == {"int": 5}
-    assert app.url_path_for("int_convertor", param=5) == "/int/5"
+    assert app.url_path_for("int_convertor", param=5) == "/int/5"  # type: ignore
 
 
 def test_route_converters_float():
@@ -35,7 +35,7 @@ def test_route_converters_float():
     response = client.get("/float/25.5")
     assert response.status_code == 200, response.text
     assert response.json() == {"float": 25.5}
-    assert app.url_path_for("float_convertor", param=25.5) == "/float/25.5"
+    assert app.url_path_for("float_convertor", param=25.5) == "/float/25.5"  # type: ignore
 
 
 def test_route_converters_path():
